function [param, ss] = calibext_fincon_use

% This file calculates the steady state for the two country growth model.
% The first half of the code calculates starting values for the dynare
% model. The second half of the code calculates end values where Chinese
% TFP is assumed to equal that in the US.

% PWT averages to match in steady state
% i/k ratio = 0.15
% labor's share = 0.59, capital's share=0.41
% Ratio of TFP in China to TFP in US average since 1996=0.37
% Ratio of China GDP/(US GDP + China GDP) = 0.21 from WEO

%cd 'U:\International\dynare\No Capital\Logs'

clear

%%%%%% Parameter values %%%%%%

xi = 0.522;                                                 % Calvo pricing parameter 0.85^4
xi_s = 0.3164;                                              % Calvo pricing parameter 0.75^4
sigma = 4;                                                  % Elasticity of demand for domestic intermediate goods
theta = 4;                                                  % Elasticity of substitution between domestic and foreign inputs for final consumption
phi = 0.34;                                                 % Frisch elasticity
phi_s = 0.34;
eta = 2;                                                    % Labour supply elasticity
%eta = 0.1;                                                 % Alternative
%eta for Figure 6 in Online Appendix
%eta = 10;                                                  % Alternative eta for Figure 6 in Online Appendix                       
%phi_m = 0.0067;                                            % Coefficient on money in the utility function to get M1/GDP in China to equal that in the US
phi_m = 0.0353;                                             % Coefficient on money supply to get M1/GDP=0.5
phi_m_s = 0.0058;                                           % Coefficient on money supply to get M1_s/GDP_s=0.1
phi_n = 1;                                                  % Coefficient on labour in the utility function
phi_n_s = 1;                                                  % Coefficient on labour in the utility function
phi_c = 1;                                                  % Coefficient on consumption the utility function
phi_c_s = 1;                                                  % Coefficient on consumption in the utility function
rho_phin = 0.9;                                                  % Coefficient on lagged labour in the utility function shock
rho_phins = 0.9;                                                  % Coefficient on lagged labour in the utility function shock
rho_phic = 0.9;                                                  % Coefficient on lagged consumption the utility function shock
rho_phics = 0.9;                                                  % Coefficient on lagged consumption in the utility function shock
rho = 1;                                                    % Risk aversion on utility function
alpha = 0.5;                                                % Share of capital in production 
alpha_s = 0.3; 
delta_s = 0.05;                    
bigpsi = 0;%3;                                                % Coefficient on investment adjustment costs1.5*10 
bigpsi_s = 0;                                              %                      0.1*10
rho_bigpsi = 0.9;                                           % Coefficient on lagged capital adjustment cost shock 
rho_bigpsis = 0.9;                                         % Coefficient on lagged capital adjustment cost shock
kappa = -0.010972;
%psi = 1;                                                  % Fraction of firm's input costs that have to be financed
psi = 0.2;                                                 
psi_s = 0;                                                   % Fraction of foreign firms costs that have to be financed
rho_A = 0.9;                                                % Autoregressive coefficient on technology process
rho_A_s = 0.9;
rho_Rfs = 0.8;
rho_Rfspi = 1.5;                                                % Coefficient on inflation in the Taylor rule
rho_Rfsgdp = 1;                                               % Coefficient on output in the Taylor rule
n = 0.25;                                                   % Share of population in the home country
%n = 0.125;                                                 % Halving size
%of home country in Figure 6
%n = 0.01;                                                  % SOE for
%Figure 6
omega = 0.7;                                                % Share of home goods in home consumption 0.7
omega_s = 0.15;                                             
phi_a = 0.01;                                               % Risk premium on foreign borrowings
rho_g = 0.3;                                                % AR(1) coefficient on productivity's long run growth rate
rho_g_s = 0.3;
bfratio = 0.124;
%bfratio = 0.05;
v = (sigma-1)/sigma;                                                      % Removing distortion from monopolistic competition
u1 = 1;                                                      % Misallocation
mv1 = 1-phi*(1-rho);
ik_ratio = 0.15;
rho_G=0.92 
rho_G_s=0.9;
fincon=0.3; % Value of capital stock that can be borrowed against, psi
%fincon=0.25;
eta_fc=0;

tau_r = 0.13;
pi_s = 1.025;
pi = 1.025;
pi_h = 1.025;
pi_h_s = 1.025;
pi_f_s = 1.025;
G = 1.012;
G_s = 1.012;
S = 1;
b_h = 0;
R_h = 1.05;
R_f_s = 1.05;
R_l = R_h/(1-tau_r);
beta = pi*G/R_h;                                            % Discount rate
beta_use = beta;
ratio = 0.33;
%ratio = 0.45;
%ratio = 0.37;
delta = ik_ratio-G+1;
%delta=delta_s;                                             % Depreciation
%in home country equal to foreign country in Figure 6
R_k = G/beta-1+delta;
%R_k = 0.2;
R_k_s = G_s/beta-1+delta_s;

% Coefficients on money supply rule (Taken from Fan et al (2011)): https://pdf.sciencedirectassets.com/272640/1-s2.0-S0164070411X00034/1-s2.0-S016407041000090X/main.pdf?X-Amz-Security-Token=IQoJb3JpZ2luX2VjEEAaCXVzLWVhc3QtMSJHMEUCIQDpEYUiAWfx6Pez9hf%2FTWqvSshmxy6orhkfEJxuvRHwWgIgRoQJNH%2BfY4UfKByh2%2BvyiyRlyt13d5OedV6HR2derBkquwUI%2BP%2F%2F%2F%2F%2F%2F%2F%2F%2F%2FARAFGgwwNTkwMDM1NDY4NjUiDBfkuqZ19jBnuU7SISqPBbyiCUGnutF3spNew%2FMpklpDgQJzL6isQbk%2FVem5viXtBDjpdx6%2FelVhT6qBYf3GWLDq%2FmGW1mvR0wjH1DU%2B7IKza16e97DBeRBPTV8nAmCKK9sWIpBObWRF97etzcHxzEYhk1CXu5gDxblccVjFEbFpOXIn8NES9q4iPxyZsIb8XkG%2Bmh0VvnYFRj9Q01dOumbzmpDxKbbObf7dtN9IMzMDMo%2Be1kzGqltrueYcEXS9imcdiV%2BDjIHYreyKQpu4%2BdUsnpzHL9zA6Hrf42V6YEcnMOI9q%2FjY%2BZsP4NyvIEPezd7dUE15x2fOzlxJX0%2BMrK3xRT0bV8ucsdfkAVTqaD424QOUKwYv5xX3gtDg7UjI6PVHWOAn1gPK1VszOZULro8vP5C%2F%2BIX7pvAWjSwaVd6uzhNrHePXpv4gK6qgUntHVvd9r0bqK2u%2F6eccnnKlkCGrRYkhiKUEH5aRKvg60R%2FWWcAXYjGlxT1vo5p1c8Ue2nJJuNcaQZCcj2yh5OXFcaoppRlaJcTOvbiljvS6PN01eqznf%2Fq5HzLXmXWwowMGkO7V%2BKq3R9QVUDS%2BjbVdC8hwOgQJfKWjATE2DfKzqlAto0svn5hKOIy0GH3umCZOunLwBlaVRQ%2FrzocAcV7Kzu0qro9STrRx2nBpX%2FADO%2F3nSA4KyrMWZLSDOWuIwMVIdEr%2BTmbydQd7kGUXJqiQZeVxWuqCDDl3vfZWF96NK2Aard%2FchIZHGpijyRn8iq4jkuB%2BrXC06AqB%2BL3Adyv%2BgLJWcnxepsPHazOnwJxjg8VNuHT6Z%2FFXb%2BKBMlTXXQObr6CDz3%2BX%2FoIo3iYxYcyQpWibhyJC1QxUOBQAoyGZ0K2llyqRpeBEiEe3JYzH5Zsw%2BoKVpwY6sQHdcSzZs2cokVxGiIk5NBVKum%2BHHdF7h%2F4vBkhC15el8sPZUkEXoEa4l7zclaJIl9cvkBKddI0OtkT%2BtHJdNDXDw4OZ2JKiFdk2XZTSxjAqx%2FHgbOqxdvnsEWHc4NXs4PasDA7yI3cGacd6WF74YKe%2B9SWY%2Ft4AcoTg275twpvSVdG%2FJxYYUQQSOvbN3pesPFTvztqBmVBAKV6al5M3GRRY4T2WEpOo6T%2BWNAD3dccvVD8%3D&X-Amz-Algorithm=AWS4-HMAC-SHA256&X-Amz-Date=20230823T000842Z&X-Amz-SignedHeaders=host&X-Amz-Expires=300&X-Amz-Credential=ASIAQ3PHCVTYXEB73R4T%2F20230823%2Fus-east-1%2Fs3%2Faws4_request&X-Amz-Signature=c843bca322186da973575b4c4dc8257057f89e7b9206a823370b8a86e4e39cf0&hash=016fe7f816f6179c2fa6c84545ce90669f080686e41e33aa51b5caa8e27e6a0a&host=68042c943591013ac2b2430a89b270f6af2c76d8dfd086a07176afe7c76c2c61&pii=S016407041000090X&tid=spdf-58ef4f04-5169-46a2-be6f-13d4f9b8d8fc&sid=7a4b200a1af92543811babf9034f5c1d4372gxrqa&type=client&tsoh=d3d3LnNjaWVuY2VkaXJlY3QuY29t&ua=04125807000154035607&rr=7faf1f5daa0ba82b&cc=au
rho_mm=0.77;
rho_mgdp=(-3.25*(1-0.45)+4.08*(1-0.32));
rho_mpi=(-0.58*(1-0.45)-1.09*(1-0.32));
rho_mQ=0;
%rho_mQ=6; %(See https://www.sciencedirect.com/science/article/pii/S0261560608000557 Table 1)
% Coefficients on money supply rule (Taken from Chen et al (2018))
%rho_mm=0.391;
%rho_mgdp=0.183;
%rho_mpi=-0.397;

% Coefficients on required reserve rule 
 rho_taur=0.928; %Correlation from the data
 rho_taurbf=0.266;
 rho_taurpi=1.039;
 rho_taurgdp=-0.965;
%rho_taur=0.990334^4; %Correlation from the quarterly data
%rho_taurbf=0.303986;
%rho_taurpi=2.132272/4;
%rho_taurgdp=-1.946740/4;
rho_taurbf_b=0.0009;
rho_taurpi_b=4.22;
rho_taurgdp_b=18.90;

% Coefficients on foreign reserve rule 
rho_bf=0.909; %Correlation from the data
rho_bfst=0.797;
%rho_bfs=1.45; %From Parrado (2004) low value https://www.imf.org/en/Publications/WP/Issues/2016/12/30/Inflation-Targeting-and-Exchange-Rate-Rules-in-an-Open-Economy-16791
rho_bfs=3%2.71; %Average from Parrado (2004)
%rho_bf=0.982193^4; %Correlation from the quarterly data
%rho_bfst=0.803898;
%rho_bfs=-3.612547;
rho_bfst_b=1.5;
rho_bfs_b=1.5;

% Coefficients on the exchange rate trend
rho_st=0.224; %Correlation from the data 
rho_stpi=0.065;
rho_stgdp=-0.133;
rho_stpigap=0.1;
rho_stgdpgap=0.1;
%rho_st=0.843206^4; %Correlation from the quarterly data 
%rho_stpi=-0.135055;
%rho_stgdp=-0.527948;
%rho_stpigap=0.1;
%rho_stgdpgap=0.1;
rho_stpi_b=0.1;
rho_stgdp_b=0.9;
rho_stpigap_b=0.1;
rho_stgdpgap_b=0.1;

% Variance around shocks
sigma_bf=1;
sigma_G=1;
sigma_G_s=1;
sigma_m=1;
sigma_tau=1;
sigma_St=1;
sigma_rho_phin = 1;
sigma_rho_phins = 1;
sigma_rho_phic = 1;
sigma_rho_phics = 1;
sigma_rho_bigpsi = 1;
sigma_rho_bigpsis = 1;
sigma_Rfs=1;

%%%% Initial values for fsolve for binding financial constraint %%%%

%initval = ones(18,1);
%initval = [0.5792 0.5295 0.1973 0.1752 0.5295 0.1624 0.8127 0 1.0728 3.9453 0.1118 1.3124 1.5213 0.9611 0.8610 0.7954 0 -1.4870]; %fincon=0.01 to 0.1
%initval = [0.4354 0.3786 0.1235 0.1439 0.3786 0.0624 0.7958 0 1.0688 3.9305 0.0858 1.3213 1.6240 0.9586 0.8610 0.7924 0 -6.4293]; %fincon=0.1 to 0.15
%initval = [0.2707 0.2139 0.0541 0.1015 0.2139 0.0124 0.7718 0 1.0634 3.9107 0.0537 1.3333 1.8233 0.9552 0.8610 0.7884 0 -41.4583]; %fincon=0.15 to 0.16 
%initval = [0.1684 0.1191 0.0223 0.0698 0.1191 0.0024 0.7527 0 1.0595 3.8961 0.0325 1.3423 2.0653 0.9527 0.8610 0.7854 0 -243.9535]; %fincon=0.16 
%initval = [1.5071 9.1866 1.2161 0.3943 0.698 1.4687	0.9336 1.6011 0.9431 4.0008 0.2517 1.0792 1.1198 0.9834 0.7167 0.969 -0.2572]; %without the constraint
%initval = [1.1250 2.5010 0.6734 0.2922 0.7120 0.5704 0.8698 0 1.0882 4.0018 0.2230 1.2792 1.2847 0.9707 0.8610 0.8067 0 0.02]
%initval = [1.1193 2.4361 0.6637 0.2904 0.7145 0.5715 0.8690 0.0000 1.0880 4.0009 0.2212 1.2797 1.2872 0.9706 0.8610 0.8066 -0.0000 0.0216] %fincon=0.33
initval = [1.1749 3.7692 0.8291 0.3184 0.6550 0.5041 0.8816 0 1.0917 4.0147 0.2505 1.2718 1.2489 0.9729 0.8610 0.8093 -0.0000 -0.5912] %fincon=0.25
%initval = [1.0854 4.9480 0.8873 0.3274 0.5555 0.3350 0.8855 0 1.0929 4.0191 0.2602 1.2693 1.2374 0.9737 0.8610 0.8102 0 -2.2978] %fincon=0.2
%initval = [0.8625 4.9797 0.7435 0.3044 0.4176 0.1504 0.8753 0 1.0898 4.0077 0.2357 1.2758 1.2675 0.9717 0.8610 0.8079 0 -8.2264] %fincon=0.175
%initval = [0.7601 4.6360 0.6453 0.2871 0.3594 0.0982 0.8675 0 1.0875 3.9992 0.2177 1.2807 1.2922 0.9703 0.8610 0.8062 0 -14.0866] %fincon=0.17
%initval = [0.7601 4.6360 0.6453 0.2871 0.3594 0.0982 0.8675 0 1.0875 3.9992 0.2177 1.2807 1.2922 0.9703 0.8610 0.8062 0 -200]
%initval = [0.8 0.3 0.3 0.2 0.5 0.3	0.8 1.6011 1 4 0.1 1.0792 1.1198 0.9834 0.7167 0.969 -0.2572 0];
options=optimset('Display','iter');  %'MaxIter', 10000, 'MaxFunEvals', 100000 
[x,fval] = fsolve(@(x) SSLPgext_fincon_use_etafc0(x, theta, ratio, omega, phi_n, eta_fc, psi, eta, sigma, alpha, delta, G, R_k, n, S, R_f_s,...
    pi, R_l, R_h, tau_r, omega_s, alpha_s, psi_s, delta_s, G_s, R_k_s, pi_s, bfratio, beta_use, fincon), initval, options);

C=x(1) 
K=x(2) 
Y_h=x(3) 
Y_f=x(4) 
N=x(5) 
W=x(6) 
Q=x(7) 
b_f=x(8)
C_s=x(9) 
K_s=x(10) 
Y_h_s=x(11) 
Y_f_s=x(12) 
p_h_s=x(13) 
p_f_s=x(14)
N_s=x(15) 
W_s=x(16) 
b_f_s=x(17)
eta_fc=x(18)
SS2 = [x(1) x(2) x(3) x(4) x(5) x(6) x(7) x(8) x(9) x(10) x(11) x(12) x(13) x(14) x(15) x(16) x(17) x(18)];

%%%% Initial values for fsolve for a non-binding financial constraint %%%%
%{
initval = [1.5071 9.1866 1.2161 0.3943 0.698 1.4687	0.9336 1.6011 0.9431 4.0008 0.2517 1.0792 1.1198 0.9834 0.7167 0.969 -0.2572]; %without the constraint
options=optimset('Display','iter');  %'MaxIter', 10000, 'MaxFunEvals', 100000 
[x,fval] = fsolve(@(x) SSLPgext_nofincon_use_etafc0(x, theta, ratio, omega, phi_n, eta_fc, psi, eta, sigma, alpha, delta, G, R_k, n, S, R_f_s,...
    pi, R_l, R_h, tau_r, omega_s, alpha_s, psi_s, delta_s, G_s, R_k_s, pi_s, bfratio, beta_use, fincon), initval, options);

C=x(1) 
K=x(2) 
Y_h=x(3) 
Y_f=x(4) 
N=x(5) 
W=x(6) 
Q=x(7) 
b_f=x(8)
C_s=x(9) 
K_s=x(10) 
Y_h_s=x(11) 
Y_f_s=x(12) 
p_h_s=x(13) 
p_f_s=x(14)
N_s=x(15) 
W_s=x(16) 
b_f_s=x(17)
eta_fc=0          

SS2 = [x(1) x(2) x(3) x(4) x(5) x(6) x(7) x(8) x(9) x(10) x(11) x(12) x(13) x(14) x(15) x(16) x(17)];
%}
%%%%

I = K*(G-1+delta);
I_s = K_s*(G_s-1+delta_s);
lambda = 1/C;
lambda_s = 1/C_s;
mu = lambda;
mu_s = lambda_s;
m = phi_m/(lambda*(1-beta/(pi*G)));
%MC = (1-psi+psi*eta_fc*R_l)*W/((1-alpha)*G^(1-alpha))*(N/K)^alpha;
p_h = p_h_s*Q;
Y = C+I;
MC_s = (1-psi_s+psi_s*R_f_s)*W_s/((1-alpha_s)*G_s^(1-alpha_s))*(N_s/K_s)^alpha_s;
Y_s = C_s + I_s;
m_s = phi_m_s/(lambda_s*(1-beta/(pi_s*G_s)));

GDPval = n*(C + I) + (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio
GDPval_s = (1-n)*(C_s + I_s) + n*p_f_s*Y_f - (1-n)*p_h_s*Y_h_s*ratio

CA = (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio + n*S*(R_f_s-1)*b_f/(pi*G);
CA_s = n*p_f_s*Y_f - (1-n)*p_h_s*Y_h_s*ratio + (1-n)*(R_f_s-1)*b_f_s/(pi_s*G_s);
TB = (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio;
TB_s = n*p_f_s*Y_f - (1-n)*p_h_s*Y_h_s*ratio;

ratio_start = ratio;
C_share = n*C/(n*(C + I) + (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio)
I_share =  n*I/(n*(C + I) + (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio)
NX_share = ((1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio)/( n*(C + I) + (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio)
X_share = ((1-n)*Q*p_h_s*Y_h_s)/( n*(C + I) + (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio)
M_share = (n*Q*p_f_s*Y_f/ratio)/( n*(C + I) + (1-n)*Q*p_h_s*Y_h_s - n*Q*p_f_s*Y_f/ratio)
pi_share = n*(p_h*K^alpha*(G*N)^(1-alpha) - (1-psi+psi*eta_fc*R_l)*(W*N+R_k*K))/GDPval
pi_firm =  n*(p_h*K^alpha*(G*N)^(1-alpha) - (1-psi+psi*eta_fc*R_l)*(W*N+R_k*K))
fincon_act = (W*N + R_k*K)/K 

%%%% End values for the model %%%%

ratio = 0.7;

initval = SS2;

%%%% Solving for binding financial constraint %%%%

options=optimset('Display','iter');  %'MaxIter', 10000, 'MaxFunEvals', 100000 
[x,fval] = fsolve(@(x) SSLPgext_fincon_use_etafc0(x, theta, ratio, omega, phi_n, eta_fc, psi, eta, sigma, alpha, delta, G, R_k, n, S, R_f_s,...
    pi, R_l, R_h, tau_r, omega_s, alpha_s, psi_s, delta_s, G_s, R_k_s, pi_s, bfratio, beta_use, fincon), initval, options);

Cend=x(1) 
Kend=x(2) 
Y_hend=x(3) 
Y_fend=x(4) 
Nend=x(5) 
Wend=x(6) 
Qend=x(7) 
b_fend=x(8)
C_send=x(9) 
K_send=x(10) 
Y_h_send=x(11) 
Y_f_send=x(12) 
p_h_send=x(13) 
p_f_send=x(14)
N_send=x(15) 
W_send=x(16) 
b_f_send=x(17)
eta_fcend=x(18)

%%%% Solving for non-binding financial constraint %%%%
%{
options=optimset('Display','iter');  %'MaxIter', 10000, 'MaxFunEvals', 100000 
[x,fval] = fsolve(@(x) SSLPgext_nofincon_use_etafc0(x, theta, ratio, omega, phi_n, eta_fc, psi, eta, sigma, alpha, delta, G, R_k, n, S, R_f_s,...
    pi, R_l, R_h, tau_r, omega_s, alpha_s, psi_s, delta_s, G_s, R_k_s, pi_s, bfratio, beta_use, fincon), initval, options);

Cend=x(1) 
Kend=x(2) 
Y_hend=x(3) 
Y_fend=x(4) 
Nend=x(5) 
Wend=x(6) 
Qend=x(7) 
b_fend=x(8)
C_send=x(9) 
K_send=x(10) 
Y_h_send=x(11) 
Y_f_send=x(12) 
p_h_send=x(13) 
p_f_send=x(14)
N_send=x(15) 
W_send=x(16) 
b_f_send=x(17)
eta_fcend=0 
%}
%%%%%%%%

Iend = Kend*(G-1+delta);
I_send = K_send*(G_s-1+delta_s);
lambdaend = 1/Cend;
lambda_send = 1/C_send;
muend = lambdaend;
mend = phi_m/(lambdaend*(1-beta/(pi*G)));
mu_send = lambda_send;
%MCend = (1-psi+psi*eta_fc*R_l)*Wend/((1-alpha)*G^(1-alpha))*(Nend/Kend)^alpha;
p_hend = p_h_send*Qend;
Yend = Cend+Iend;
MC_send = (1-psi_s+psi_s*R_f_s)*W_send/((1-alpha_s)*G_s^(1-alpha_s))*(N_send/K_send)^alpha_s;
Y_send = C_send + I_send;
m_send = phi_m_s/(lambda_send*(1-beta/(pi_s*G_s)));

GDPvalend = n*(Cend + Iend) + (1-n)*Qend*p_h_send*Y_h_send - n*Qend*p_f_send*Y_fend/ratio;
GDPval_send = (1-n)*(C_send + I_send) + n*p_f_send*Y_fend - (1-n)*p_h_send*Y_h_send*ratio;

CAend = (1-n)*Qend*p_h_send*Y_h_send - n*Qend*p_f_send*Y_fend/ratio + n*S*(R_f_s-1)*b_fend/(pi*G);
CA_send = n*p_f_send*Y_fend - (1-n)*p_h_send*Y_h_send*ratio + (1-n)*(R_f_s-1)*b_f_send/(pi_s*G_s);
TBend = (1-n)*Qend*p_h_send*Y_h_send - n*Qend*p_f_send*Y_fend/ratio;
TB_send = n*p_f_send*Y_fend - (1-n)*p_h_send*Y_h_send*ratio;
pi_share_end = n*(p_hend*Kend^alpha*(G*Nend)^(1-alpha) - (1-psi+psi*eta_fc*R_l)*(Wend*Nend+R_k*Kend))/GDPvalend;
pi_firm_end = n*(p_hend*Kend^alpha*(G*Nend)^(1-alpha) - (1-psi+psi*eta_fc*R_l)*(Wend*Nend+R_k*Kend));
fincon_actend = (Wend*Nend + R_k*Kend)/Kend;

ratioend=ratio;

% Logging the data

pi = log(pi);
p_h = log(p_h);
S = log(S);
G = log(G);
Q = log(Q);
K = log(K);
Y = log(Y);
C = log(C);
N = log(N);    
lambda = log(lambda);
W = log(W);
mu = log(mu);
I = log(I);
R_k = R_k;
R_h = R_h;
R_l = R_l;
b_f = b_f;
tau_r = tau_r;
%MC = log(MC);
Y_h = log(Y_h);
Y_f = log(Y_f);
m = log(m);
pi_s = log(pi_s);
p_f_s = log(p_f_s);
p_h_s = log(p_h_s);
G_s = log(G_s);
K_s = log(K_s);
Y_s = log(Y_s);
C_s = log(C_s);
N_s = log(N_s);    
lambda_s = log(lambda_s);
W_s = log(W_s);
mu_s = log(mu_s);
I_s = log(I_s);
R_k_s = R_k_s;
b_f_s = b_f_s;
MC_s = log(MC_s);
Y_h_s = log(Y_h_s);
Y_f_s = log(Y_f_s);
R_f_s = R_f_s;
ratio = log(ratio_start);
m_s = log(m_s);
phi_n = log(phi_n);
phi_n_s = log(phi_n_s);
phi_c = log(phi_c);
phi_c_s = log(phi_c_s);
bigpsi = log(bigpsi);
bigpsi_s = log(bigpsi_s);

GDPval = log(GDPval);
GDPval_s = log(GDPval_s);
CA = CA;
CA_s = CA_s;
TB = TB;
TB_s = TB_s;

piend = pi;
p_hend = log(p_hend);
Send = S;
Gend = G;
Qend = log(Qend);
Kend = log(Kend);
Yend = log(Yend);
Cend = log(Cend);
Nend = log(Nend);    
lambdaend = log(lambdaend);
Wend = log(Wend);
muend = log(muend);
Iend = log(Iend);
R_kend = R_k;
R_hend = R_h;
R_lend = R_l;
b_fend = b_fend;
tau_rend = tau_r;
%MCend = log(MCend);
Y_hend = log(Y_hend);
Y_fend = log(Y_fend);
pi_hend = log(pi_h);
pi_h_send = log(pi_h_s);
mend = log(mend);
pi_send = pi_s;
p_f_send = log(p_f_send);
p_h_send = log(p_h_send);
G_send = G_s;
K_send = log(K_send);
Y_send = log(Y_send);
C_send = log(C_send);
N_send = log(N_send);    
lambda_send = log(lambda_send);
W_send = log(W_send);
mu_send = log(mu_send);
I_send = log(I_send);
R_k_send = R_k_s;
b_f_send = b_f_send;
MC_send = log(MC_send);
Y_h_send = log(Y_h_send);
Y_f_send = log(Y_f_send);
pi_f_send = pi_f_s;
R_f_send = R_f_s;
ratioend = log(ratioend);
m_send = log(m_send)
phi_nend = log(phi_n);
phi_n_send = log(phi_n_s);
phi_cend = log(phi_c);
phi_c_send = log(phi_c_s);
bigpsiend = log(bigpsi);
bigpsi_send = log(bigpsi_s);

GDPvalend = log(GDPvalend);
GDPval_send = log(GDPval_send);
CAend = CAend;
CA_send = CA_send;
TBend = TBend;
TB_send = TB_send;


param = [beta, sigma, theta, eta, phi_m, alpha, alpha_s, delta, delta_s, bigpsi, bigpsi_s, psi, psi_s, n, omega, omega_s, phi_a, phi_n, kappa,...
    phi_m, rho_mm, rho_mgdp, rho_mpi, rho_taur, rho_taurbf, rho_taurpi, rho_taurgdp, rho_bf, rho_bfst, rho_bfs, rho_st, rho_stpi, sigma_bf,...
    sigma_G, sigma_G_s, sigma_m, sigma_tau, sigma_St, rho_stgdp, rho_phin, rho_phins, rho_phic, rho_phics, rho_bigpsi, rho_bigpsis, sigma_rho_phin,...
    sigma_rho_phins, sigma_rho_phic, sigma_rho_phics, sigma_rho_bigpsi, sigma_rho_bigpsis, rho_mQ, sigma_Rfs, rho_Rfs, rho_Rfspi, rho_Rfsgdp, rho_stpigap,...
    rho_stgdpgap, rho_G, rho_G_s, phi_m_s, fincon]';
ss = [p_h, Y, Y_h, Y_f, C, lambda, N, W, m, pi, G, R_h, b_f, I, K, mu, R_k, p_h_s, Q, ratio, S, p_f_s, R_f_s, Y_h_s, pi_s, Y_s, Y_f_s, C_s, lambda_s,...
    N_s, W_s, m_s, G_s, mu_s, I_s, K_s, R_k_s, MC_s, b_f_s, GDPval, GDPval_s, CA, CA_s, TB, TB_s,...
    p_hend, Yend, Y_hend, Y_fend, Cend, lambdaend, Nend, Wend, mend, piend, Gend, R_hend, b_fend, Iend, Kend, muend, R_kend, p_h_send, Qend,...
    ratioend, Send, p_f_send, R_f_send, Y_h_send, pi_send, Y_send, Y_f_send, C_send, lambda_send,N_send, W_send, m_send, G_send, mu_send, I_send, K_send,...
    R_k_send, b_f_send, GDPvalend, GDPval_send, CAend, CA_send, TBend, TB_send, tau_r, R_l, tau_rend, R_lend,...
    phi_c, phi_c_s, bigpsi, bigpsi_s, pi_share, pi_share_end, pi_firm, pi_firm_end, MC_send, eta_fc, eta_fcend, fincon_act, fincon_actend]';


save('SSparam.mat','param','ss');

%save ('Steady_state', 'param', 'ss')



